Welcome to the PDFMathTranslate wiki!  
欢迎访问 PDFMathTranslate 维基百科！

# 🌐 Language Codes / 语言代码
If you're looking for language codes for individual translation services, you can [refer here](https://github.com/PDFMathTranslate/PDFMathTranslate-next/wiki/Language-Codes----%E8%AF%AD%E8%A8%80%E4%BB%A3%E7%A0%81). Please note, however, that these tables are organized by AI and may not be accurate, so please check the source page if you encounter problems.  
如果你在寻找各个翻译服务的语言代码，可以[参考这里](https://github.com/PDFMathTranslate/PDFMathTranslate-next/wiki/Language-Codes----%E8%AF%AD%E8%A8%80%E4%BB%A3%E7%A0%81)。但请注意，这些表格由 AI 整理、可能并不准确，如果遇到问题请到源网页确认。

# 📄 Documentation of Translation Services / 翻译服务文档
If you are looking for more information on various translation services, please [refer here](https://github.com/PDFMathTranslate/PDFMathTranslate-next/wiki/Documentation-of-Translation-Services----%E7%BF%BB%E8%AF%91%E6%9C%8D%E5%8A%A1%E6%96%87%E6%A1%A3).  
如果你在寻找各个翻译服务的更多信息，请参阅[这里](https://github.com/PDFMathTranslate/PDFMathTranslate-next/wiki/Documentation-of-Translation-Services----%E7%BF%BB%E8%AF%91%E6%9C%8D%E5%8A%A1%E6%96%87%E6%A1%A3)。
